==> ZenTaoPMS.12.5.2.zip: zentaopms/module/group/lang/vi.php <==
<?php
/**
 * The group module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license  ZPL (http://zpl.pub/page/zplv12.html)
 * @author   Nguyễn Quốc Nho <quocnho@gmail.com>
 * @package  group
 * @version  $Id: vi.php 4719 2013-05-03 02:20:28Z quocnho@gmail.com $
 * @link  http://www.zentao.net
 */
$lang->group->common             = 'Phân quyền';
$lang->group->browse             = 'Nhóm quyền';
$lang->group->create             = 'Tạo Group';
$lang->group->edit               = 'Sửa Group';
$lang->group->copy               = 'Copy Group';
$lang->group->delete             = 'Xóa Group';
$lang->group->manageView         = 'Quản lý Sight';
$lang->group->managePriv         = 'Quản lý Privileges';
$lang->group->managePrivByGroup  = 'Quản lý Privileges by Group';
$lang->group->managePrivByModule = 'Quản lý Privileges by Module';
$lang->group->byModuleTips       = '<span class="tips">(Press Shift/Ctrl to Multi-select)</span>';
$lang->group->manageMember       = 'Quản lý Members';
$lang->group->confirmDelete      = 'Bạn có muốn xóa người dùng này group?';
$lang->group->successSaved       = 'Đã lưu.';
$lang->group->errorNotSaved      = 'Thất bại.  Vui lòng select actions and groups.';
$lang->group->viewList           = 'Truy cập Sight';
$lang->group->productList        = 'Truy cập Product';
$lang->group->projectList        = 'Truy cập Project';
$lang->group->dynamic            = 'Truy cập Dynamics';
$lang->group->noticeVisit        = 'Blank means no access limit.';
$lang->group->noneProduct        = "Không có {$lang->productCommon}";
$lang->group->noneProject        = "Không có {$lang->projectCommon}";

$lang->group->id      = 'ID';
$lang->group->name    = 'Nhóm';
$lang->group->desc    = 'Mô tả';
$lang->group->role    = 'Vai trò';
$lang->group->acl     = 'Right';
$lang->group->users   = 'Nhóm Members';
$lang->group->module  = 'Module';
$lang->group->method  = 'Phương thức';
$lang->group->priv    = 'Nhóm quyền';
$lang->group->option  = 'Tùy chọn';
$lang->group->inside  = 'Nhóm người dùng';
$lang->group->outside = 'Other người dùng';
$lang->group->other   = 'Khác';
$lang->group->all     = 'Tất cả Privileges';

$lang->group->copyOptions['copyPriv'] = 'Copy Privileges';
$lang->group->copyOptions['copyUser'] = 'Copy người dùng';

$lang->group->versions['']           = 'Lịch sử';
$lang->group->versions['12_5']       = 'ZenTao12.5';
$lang->group->versions['12_3']       = 'ZenTao12.3';
$lang->group->versions['11_6_2']     = 'ZenTao11.6.2';
$lang->group->versions['10_6']       = 'ZenTao10.6';
$lang->group->versions['10_1']       = 'ZenTao10.1';
$lang->group->versions['10_0_alpha'] = 'ZenTao10.0.alpha';
$lang->group->versions['9_8']        = 'ZenTao9.8';
$lang->group->versions['9_6']        = 'ZenTao9.6';
$lang->group->versions['9_5']        = 'ZenTao9.5';
$lang->group->versions['9_2']        = 'ZenTao9.2';
$lang->group->versions['9_1']        = 'ZenTao9.1';
$lang->group->versions['9_0']        = 'ZenTao9.0';
$lang->group->versions['8_4']        = 'ZenTao8.4';
$lang->group->versions['8_3']        = 'ZenTao8.3';
$lang->group->versions['8_2_beta']   = 'ZenTao8.2.beta';
$lang->group->versions['8_0_1']      = 'ZenTao8.0.1';
$lang->group->versions['8_0']        = 'ZenTao8.0';
$lang->group->versions['7_4_beta']   = 'ZenTao7.4.beta';
$lang->group->versions['7_3']        = 'ZenTao7.3';
$lang->group->versions['7_2']        = 'ZenTao7.2';
$lang->group->versions['7_1']        = 'ZenTao7.1';
$lang->group->versions['6_4']        = 'ZenTao6.4';
$lang->group->versions['6_3']        = 'ZenTao6.3';
$lang->group->versions['6_2']        = 'ZenTao6.2';
$lang->group->versions['6_1']        = 'ZenTao6.1';
$lang->group->versions['5_3']        = 'ZenTao5.3';
$lang->group->versions['5_1']        = 'ZenTao5.1';
$lang->group->versions['5_0_beta2']  = 'ZenTao5.0.beta2';
$lang->group->versions['5_0_beta1']  = 'ZenTao5.0.beta1';
$lang->group->versions['4_3_beta']   = 'ZenTao4.3.beta';
$lang->group->versions['4_2_beta']   = 'ZenTao4.2.beta';
$lang->group->versions['4_1']        = 'ZenTao4.1';
$lang->group->versions['4_0_1']      = 'ZenTao4.0.1';
$lang->group->versions['4_0']        = 'ZenTao4.0';
$lang->group->versions['4_0_beta2']  = 'ZenTao4.0.beta2';
$lang->group->versions['4_0_beta1']  = 'ZenTao4.0.beta1';
$lang->group->versions['3_3']        = 'ZenTao3.3';
$lang->group->versions['3_2_1']      = 'ZenTao3.2.1';
$lang->group->versions['3_2']        = 'ZenTao3.2';
$lang->group->versions['3_1']        = 'ZenTao3.1';
$lang->group->versions['3_0_beta2']  = 'ZenTao3.0.beta2';
$lang->group->versions['3_0_beta1']  = 'ZenTao3.0.beta1';
$lang->group->versions['2_4']        = 'ZenTao2.4';
$lang->group->versions['2_3']        = 'ZenTao2.3';
$lang->group->versions['2_2']        = 'ZenTao2.2';
$lang->group->versions['2_1']        = 'ZenTao2.1';
$lang->group->versions['2_0']        = 'ZenTao2.0';
$lang->group->versions['1_5']        = 'ZenTao1.5';
$lang->group->versions['1_4']        = 'ZenTao1.4';
$lang->group->versions['1_3']        = 'ZenTao1.3';
$lang->group->versions['1_2']        = 'ZenTao1.2';
$lang->group->versions['1_1']        = 'ZenTao1.1';
$lang->group->versions['1_0_1']      = 'ZenTao1.0.1';

include (dirname(__FILE__) . '/resource.php');

==> ZenTaoPMS.15.0.2.zip: zentaopms/module/group/lang/vi.php <==
<?php
/**
 * The group module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license  ZPL (http://zpl.pub/page/zplv12.html)
 * @author   Nguyễn Quốc Nho <quocnho@gmail.com>
 * @package  group
 * @version  $Id: vi.php 4719 2013-05-03 02:20:28Z quocnho@gmail.com $
 * @link  http://www.zentao.net
 */
$lang->group->common             = 'Phân quyền';
$lang->group->browse             = 'Nhóm quyền';
$lang->group->create             = 'Tạo Group';
$lang->group->edit               = 'Sửa Group';
$lang->group->copy               = 'Copy Group';
$lang->group->delete             = 'Xóa Group';
$lang->group->manageView         = 'Quản lý Sight';
$lang->group->managePriv         = 'Quản lý Privileges';
$lang->group->managePrivByGroup  = 'Quản lý Privileges by Group';
$lang->group->managePrivByModule = 'Quản lý Privileges by Module';
$lang->group->byModuleTips       = '<span class="tips">(Press Shift/Ctrl to Multi-select)</span>';
$lang->group->manageMember       = 'Quản lý Members';
$lang->group->manageProjectAdmin = 'Manage Program Admins';
$lang->group->confirmDelete      = 'Bạn có muốn xóa người dùng này group?';
$lang->group->successSaved       = 'Đã lưu.';
$lang->group->errorNotSaved      = 'Thất bại.  Vui lòng select actions and groups.';
$lang->group->viewList           = 'Truy cập Sight';
$lang->group->manageProject      = 'Manage Project';
$lang->group->programList        = 'Truy cập Program';
$lang->group->productList        = 'Truy cập Product';
$lang->group->projectList        = 'Truy cập Project';
$lang->group->dynamic            = 'Truy cập Dynamics';
$lang->group->noticeVisit        = 'Blank means no access limit.';
$lang->group->noneProgram        = "No Program";
$lang->group->noneProduct        = "Không có {$lang->productCommon}";
$lang->group->noneProject        = "Không có {$lang->executionCommon}";

$lang->group->id      = 'ID';
$lang->group->name    = 'Nhóm';
$lang->group->desc    = 'Mô tả';
$lang->group->role    = 'Vai trò';
$lang->group->acl     = 'Right';
$lang->group->users   = 'Nhóm Members';
$lang->group->module  = 'Module';
$lang->group->method  = 'Phương thức';
$lang->group->priv    = 'Nhóm quyền';
$lang->group->option  = 'Tùy chọn';
$lang->group->inside  = 'Nhóm người dùng';
$lang->group->outside = 'Other người dùng';
$lang->group->limited  = 'Limited Users';
$lang->group->other   = 'Khác';
$lang->group->all     = 'Tất cả Privileges';

$lang->group->copyOptions['copyPriv'] = 'Copy Privileges';
$lang->group->copyOptions['copyUser'] = 'Copy người dùng';

$lang->group->versions['']           = 'Lịch sử';
$lang->group->versions['15_0_rc1']  = 'ZenTao15.0.rc1';
$lang->group->versions['12_5']       = 'ZenTao12.5';
$lang->group->versions['12_3']       = 'ZenTao12.3';
$lang->group->versions['11_6_2']     = 'ZenTao11.6.2';
$lang->group->versions['10_6']       = 'ZenTao10.6';
$lang->group->versions['10_1']       = 'ZenTao10.1';
$lang->group->versions['10_0_alpha'] = 'ZenTao10.0.alpha';
$lang->group->versions['9_8']        = 'ZenTao9.8';
$lang->group->versions['9_6']        = 'ZenTao9.6';
$lang->group->versions['9_5']        = 'ZenTao9.5';
$lang->group->versions['9_2']        = 'ZenTao9.2';
$lang->group->versions['9_1']        = 'ZenTao9.1';
$lang->group->versions['9_0']        = 'ZenTao9.0';
$lang->group->versions['8_4']        = 'ZenTao8.4';
$lang->group->versions['8_3']        = 'ZenTao8.3';
$lang->group->versions['8_2_beta']   = 'ZenTao8.2.beta';
$lang->group->versions['8_0_1']      = 'ZenTao8.0.1';
$lang->group->versions['8_0']        = 'ZenTao8.0';
$lang->group->versions['7_4_beta']   = 'ZenTao7.4.beta';
$lang->group->versions['7_3']        = 'ZenTao7.3';
$lang->group->versions['7_2']        = 'ZenTao7.2';
$lang->group->versions['7_1']        = 'ZenTao7.1';
$lang->group->versions['6_4']        = 'ZenTao6.4';
$lang->group->versions['6_3']        = 'ZenTao6.3';
$lang->group->versions['6_2']        = 'ZenTao6.2';
$lang->group->versions['6_1']        = 'ZenTao6.1';
$lang->group->versions['5_3']        = 'ZenTao5.3';
$lang->group->versions['5_1']        = 'ZenTao5.1';
$lang->group->versions['5_0_beta2']  = 'ZenTao5.0.beta2';
$lang->group->versions['5_0_beta1']  = 'ZenTao5.0.beta1';
$lang->group->versions['4_3_beta']   = 'ZenTao4.3.beta';
$lang->group->versions['4_2_beta']   = 'ZenTao4.2.beta';
$lang->group->versions['4_1']        = 'ZenTao4.1';
$lang->group->versions['4_0_1']      = 'ZenTao4.0.1';
$lang->group->versions['4_0']        = 'ZenTao4.0';
$lang->group->versions['4_0_beta2']  = 'ZenTao4.0.beta2';
$lang->group->versions['4_0_beta1']  = 'ZenTao4.0.beta1';
$lang->group->versions['3_3']        = 'ZenTao3.3';
$lang->group->versions['3_2_1']      = 'ZenTao3.2.1';
$lang->group->versions['3_2']        = 'ZenTao3.2';
$lang->group->versions['3_1']        = 'ZenTao3.1';
$lang->group->versions['3_0_beta2']  = 'ZenTao3.0.beta2';
$lang->group->versions['3_0_beta1']  = 'ZenTao3.0.beta1';
$lang->group->versions['2_4']        = 'ZenTao2.4';
$lang->group->versions['2_3']        = 'ZenTao2.3';
$lang->group->versions['2_2']        = 'ZenTao2.2';
$lang->group->versions['2_1']        = 'ZenTao2.1';
$lang->group->versions['2_0']        = 'ZenTao2.0';
$lang->group->versions['1_5']        = 'ZenTao1.5';
$lang->group->versions['1_4']        = 'ZenTao1.4';
$lang->group->versions['1_3']        = 'ZenTao1.3';
$lang->group->versions['1_2']        = 'ZenTao1.2';
$lang->group->versions['1_1']        = 'ZenTao1.1';
$lang->group->versions['1_0_1']      = 'ZenTao1.0.1';

include (dirname(__FILE__) . '/resource.php');
